# CHANGELOG

<!-- Template for next release -->
<!-- ## Version: development (unreleased) -->

## Version: 1.0.1 (17/09/2023)

* \#4 Fix setup config

## Version: 1.0.0 (17/09/2023)

* \#2 Add changelog and readme
* \#1 Add exisiting project
